function [ d2,d_od2 ] = vzd_odraz_koryto( h_l,h_s,alfa,d,vzd_brehu )
% VSTUP: h_l    - vyska anteny nad hladinou
%        h_s    - vyska satelitu nad hladinou
%        d      - vzdalenost prumetu lode a satelitu na vodni hladinu
%        vzd_brehu  - vdalenost lode od brehu reky
if alfa==0
    d_od2=0;
    d2=0;
else
d_pr=sqrt((d^2)+((h_s-h_l)^2)); 
h_l2=(vzd_brehu*(tan(alfa))+h_l)*cos(alfa);
h_s2=(vzd_brehu*(tan(alfa))+h_s)*cos(alfa);
d2=sqrt((d_pr^2)+((h_s2-h_l2)^2));
d_od2=sqrt((d2^2)+((h_s2+h_l2)^2));
end
end

